- generateParseException() - Method in class net.sf.jsqlparser.parser.CCJSqlParser
-
Generate ParseException.
- getAlias() - Method in class net.sf.jsqlparser.schema.Table
-
- getAlias() - Method in class net.sf.jsqlparser.statement.select.ExpressionListItem
-
- getAlias() - Method in interface net.sf.jsqlparser.statement.select.FromItem
-
- getAlias() - Method in class net.sf.jsqlparser.statement.select.FunctionItem
-
- getAlias() - Method in class net.sf.jsqlparser.statement.select.LateralSubSelect
-
- getAlias() - Method in class net.sf.jsqlparser.statement.select.SelectExpressionItem
-
- getAlias() - Method in class net.sf.jsqlparser.statement.select.SubJoin
-
- getAlias() - Method in class net.sf.jsqlparser.statement.select.SubSelect
-
- getAlias() - Method in class net.sf.jsqlparser.statement.select.ValuesList
-
- getArgumentsStringList() - Method in class net.sf.jsqlparser.statement.create.table.ColDataType
-
- getBeginColumn() - Method in class net.sf.jsqlparser.parser.SimpleCharStream
-
Get token beginning column number.
- getBeginLine() - Method in class net.sf.jsqlparser.parser.SimpleCharStream
-
Get token beginning line number.
- getBetweenExpressionEnd() - Method in class net.sf.jsqlparser.expression.operators.relational.Between
-
- getBetweenExpressionStart() - Method in class net.sf.jsqlparser.expression.operators.relational.Between
-
- getBuffer() - Method in class net.sf.jsqlparser.util.deparser.CreateIndexDeParser
-
- getBuffer() - Method in class net.sf.jsqlparser.util.deparser.CreateTableDeParser
-
- getBuffer() - Method in class net.sf.jsqlparser.util.deparser.CreateViewDeParser
-
- getBuffer() - Method in class net.sf.jsqlparser.util.deparser.DeleteDeParser
-
- getBuffer() - Method in class net.sf.jsqlparser.util.deparser.ExpressionDeParser
-
- getBuffer() - Method in class net.sf.jsqlparser.util.deparser.InsertDeParser
-
- getBuffer() - Method in class net.sf.jsqlparser.util.deparser.ReplaceDeParser
-
- getBuffer() - Method in class net.sf.jsqlparser.util.deparser.SelectDeParser
-
- getBuffer() - Method in class net.sf.jsqlparser.util.deparser.StatementDeParser
-
- getBuffer() - Method in class net.sf.jsqlparser.util.deparser.UpdateDeParser
-
- getCause() - Method in exception net.sf.jsqlparser.JSQLParserException
-
- getColDataType() - Method in class net.sf.jsqlparser.statement.create.table.ColumnDefinition
-
- getColumn() - Method in class net.sf.jsqlparser.parser.SimpleCharStream
-
Deprecated.
- getColumnDefinitions() - Method in class net.sf.jsqlparser.statement.create.table.CreateTable
-
- getColumnName() - Method in class net.sf.jsqlparser.schema.Column
-
- getColumnName() - Method in class net.sf.jsqlparser.statement.create.table.ColumnDefinition
-
- getColumnNames() - Method in class net.sf.jsqlparser.statement.create.view.CreateView
-
- getColumnNames() - Method in class net.sf.jsqlparser.statement.select.ValuesList
-
- getColumns() - Method in class net.sf.jsqlparser.statement.insert.Insert
-
Get the columns (found in "INSERT INTO (col1,col2..) [...]" )
- getColumns() - Method in class net.sf.jsqlparser.statement.replace.Replace
-
A list of
Columns either from a "REPLACE
mytab (col1, col2) [...]" or a "REPLACE mytab SET col1=exp1, col2=exp2".
- getColumns() - Method in class net.sf.jsqlparser.statement.update.Update
-
The
Columns in this update (as col1 and
col2 in UPDATE col1='a', col2='b')
- getColumnsNames() - Method in class net.sf.jsqlparser.statement.create.table.Index
-
A list of strings of all the columns regarding this index
- getColumnSpecStrings() - Method in class net.sf.jsqlparser.statement.create.table.ColumnDefinition
-
A list of strings of every word after the datatype of the column.
- getDataType() - Method in class net.sf.jsqlparser.statement.create.table.ColDataType
-
- getDefaultValue() - Method in class net.sf.jsqlparser.expression.AnalyticExpression
-
- getDistinct() - Method in class net.sf.jsqlparser.statement.select.PlainSelect
-
- getElseExpression() - Method in class net.sf.jsqlparser.expression.CaseExpression
-
- getEndColumn() - Method in class net.sf.jsqlparser.parser.SimpleCharStream
-
Get token end column number.
- getEndLine() - Method in class net.sf.jsqlparser.parser.SimpleCharStream
-
Get token end line number.
- getEscape() - Method in class net.sf.jsqlparser.expression.operators.relational.LikeExpression
-
- getExpression() - Method in class net.sf.jsqlparser.expression.AnalyticExpression
-
- getExpression() - Method in class net.sf.jsqlparser.expression.ExtractExpression
-
- getExpression() - Method in class net.sf.jsqlparser.expression.InverseExpression
-
- getExpression() - Method in class net.sf.jsqlparser.expression.Parenthesis
-
- getExpression() - Method in class net.sf.jsqlparser.statement.select.OrderByElement
-
- getExpression() - Method in class net.sf.jsqlparser.statement.select.SelectExpressionItem
-
- getExpressionList() - Method in class net.sf.jsqlparser.statement.select.ExpressionListItem
-
- getExpressions() - Method in class net.sf.jsqlparser.expression.operators.relational.ExpressionList
-
- getExpressions() - Method in class net.sf.jsqlparser.statement.replace.Replace
-
A list of
Expressions (from a
"REPLACE mytab SET col1=exp1, col2=exp2").
- getExpressions() - Method in class net.sf.jsqlparser.statement.update.Update
-
The
Expressions in this update (as 'a' and 'b' in UPDATE
col1='a', col2='b')
- getExpressionVisitor() - Method in class net.sf.jsqlparser.util.deparser.DeleteDeParser
-
- getExpressionVisitor() - Method in class net.sf.jsqlparser.util.deparser.InsertDeParser
-
- getExpressionVisitor() - Method in class net.sf.jsqlparser.util.deparser.ReplaceDeParser
-
- getExpressionVisitor() - Method in class net.sf.jsqlparser.util.deparser.SelectDeParser
-
- getExpressionVisitor() - Method in class net.sf.jsqlparser.util.deparser.UpdateDeParser
-
- getExprList() - Method in class net.sf.jsqlparser.expression.operators.relational.MultiExpressionList
-
- getForColumns() - Method in class net.sf.jsqlparser.statement.select.Pivot
-
- getFormatedList(List<?>, String) - Static method in class net.sf.jsqlparser.statement.select.PlainSelect
-
- getFormatedList(List<?>, String, boolean, boolean) - Static method in class net.sf.jsqlparser.statement.select.PlainSelect
-
- getFromItem() - Method in class net.sf.jsqlparser.statement.select.PlainSelect
-
- getFromItem() - Method in class net.sf.jsqlparser.statement.update.Update
-
- getFunction() - Method in class net.sf.jsqlparser.statement.select.FunctionItem
-
- getFunctionItems() - Method in class net.sf.jsqlparser.statement.select.Pivot
-
- getGroupByColumnReferences() - Method in class net.sf.jsqlparser.statement.select.PlainSelect
-
- getHaving() - Method in class net.sf.jsqlparser.statement.select.PlainSelect
-
- GetImage() - Method in class net.sf.jsqlparser.parser.SimpleCharStream
-
Get token literal value.
- getIndex() - Method in class net.sf.jsqlparser.statement.create.index.CreateIndex
-
The index to be created
- getIndexes() - Method in class net.sf.jsqlparser.statement.create.table.CreateTable
-
A list of
Indexes (for example "PRIMARY KEY") of this table.
- getInItems() - Method in class net.sf.jsqlparser.statement.select.Pivot
-
- getInSelect() - Method in class net.sf.jsqlparser.statement.select.PivotXml
-
- getInto() - Method in class net.sf.jsqlparser.statement.select.PlainSelect
-
- getItemsList() - Method in class net.sf.jsqlparser.statement.insert.Insert
-
Get the values (as VALUES (...) or SELECT)
- getItemsList() - Method in class net.sf.jsqlparser.statement.replace.Replace
-
An
ItemsList (either from a "REPLACE mytab VALUES (exp1,exp2)" or
a "REPLACE mytab SELECT * FROM mytab2") it is null in case of a "REPLACE
mytab SET col1=exp1, col2=exp2"
- getJoin() - Method in class net.sf.jsqlparser.statement.select.SubJoin
-
- getJoins() - Method in class net.sf.jsqlparser.statement.select.PlainSelect
-
- getJoins() - Method in class net.sf.jsqlparser.statement.update.Update
-
- getLeft() - Method in class net.sf.jsqlparser.statement.select.SubJoin
-
- getLeftExpression() - Method in class net.sf.jsqlparser.expression.BinaryExpression
-
- getLeftExpression() - Method in class net.sf.jsqlparser.expression.CastExpression
-
- getLeftExpression() - Method in class net.sf.jsqlparser.expression.operators.relational.Between
-
- getLeftExpression() - Method in class net.sf.jsqlparser.expression.operators.relational.InExpression
-
- getLeftExpression() - Method in class net.sf.jsqlparser.expression.operators.relational.IsNullExpression
-
- getLeftItemsList() - Method in class net.sf.jsqlparser.expression.operators.relational.InExpression
-
- getLimit() - Method in class net.sf.jsqlparser.statement.select.PlainSelect
-
- getLimit() - Method in class net.sf.jsqlparser.statement.select.SetOperationList
-
- getLine() - Method in class net.sf.jsqlparser.parser.SimpleCharStream
-
Deprecated.
- getMessage() - Method in error net.sf.jsqlparser.parser.TokenMgrError
-
You can also modify the body of this method to customize your error messages.
- getMultiExpressionList() - Method in class net.sf.jsqlparser.statement.select.ValuesList
-
- getMultiInItems() - Method in class net.sf.jsqlparser.statement.select.Pivot
-
- getName() - Method in class net.sf.jsqlparser.expression.AnalyticExpression
-
- getName() - Method in class net.sf.jsqlparser.expression.ExtractExpression
-
- getName() - Method in class net.sf.jsqlparser.expression.Function
-
The name of he function, i.e.
- getName() - Method in class net.sf.jsqlparser.expression.JdbcNamedParameter
-
The name of the parameter
- getName() - Method in class net.sf.jsqlparser.schema.Table
-
- getName() - Method in class net.sf.jsqlparser.statement.create.table.Index
-
- getName() - Method in class net.sf.jsqlparser.statement.drop.Drop
-
- getName() - Method in class net.sf.jsqlparser.statement.select.WithItem
-
The name of this WITH item (for example, "myWITH" in "WITH myWITH AS
(SELECT A,B,C))"
- getNextAlias() - Method in class net.sf.jsqlparser.util.AddAliasesVisitor
-
Calculate next alias name to use.
- getNextToken() - Method in class net.sf.jsqlparser.parser.CCJSqlParser
-
Get the next Token.
- getNextToken() - Method in class net.sf.jsqlparser.parser.CCJSqlParserTokenManager
-
Get the next Token.
- getNotExcapedValue() - Method in class net.sf.jsqlparser.expression.StringValue
-
- getOffset() - Method in class net.sf.jsqlparser.expression.AnalyticExpression
-
- getOffset() - Method in class net.sf.jsqlparser.statement.select.Limit
-
- getOldOracleJoinSyntax() - Method in class net.sf.jsqlparser.expression.operators.relational.InExpression
-
- getOldOracleJoinSyntax() - Method in class net.sf.jsqlparser.expression.operators.relational.OldOracleJoinBinaryExpression
-
- getOldOracleJoinSyntax() - Method in interface net.sf.jsqlparser.expression.operators.relational.SupportsOldOracleJoinSyntax
-
- getOnExpression() - Method in class net.sf.jsqlparser.statement.select.Join
-
Returns the "ON" expression (if any)
- getOnSelectItems() - Method in class net.sf.jsqlparser.statement.select.Distinct
-
A list of
SelectItems expressions, as in "select DISTINCT ON
(a,b,c) a,b FROM..."
- getOperations() - Method in class net.sf.jsqlparser.statement.select.SetOperationList
-
- getOrderByElements() - Method in class net.sf.jsqlparser.expression.AnalyticExpression
-
- getOrderByElements() - Method in class net.sf.jsqlparser.statement.select.PlainSelect
-
- getOrderByElements() - Method in class net.sf.jsqlparser.statement.select.SetOperationList
-
- getParameter() - Method in class net.sf.jsqlparser.expression.IntervalExpression
-
- getParameters() - Method in class net.sf.jsqlparser.expression.Function
-
The list of parameters of the function (if any, else null) If the
parameter is "*", allColumns is set to true
- getParameters() - Method in class net.sf.jsqlparser.statement.drop.Drop
-
- getPartitionByColumns() - Method in class net.sf.jsqlparser.expression.AnalyticExpression
-
- getPivot() - Method in class net.sf.jsqlparser.schema.Table
-
- getPivot() - Method in interface net.sf.jsqlparser.statement.select.FromItem
-
- getPivot() - Method in class net.sf.jsqlparser.statement.select.LateralSubSelect
-
- getPivot() - Method in class net.sf.jsqlparser.statement.select.SubJoin
-
- getPivot() - Method in class net.sf.jsqlparser.statement.select.SubSelect
-
- getPivot() - Method in class net.sf.jsqlparser.statement.select.ValuesList
-
- getPlainSelects() - Method in class net.sf.jsqlparser.statement.select.SetOperationList
-
- getReferencedColumnNames() - Method in class net.sf.jsqlparser.statement.create.table.ForeignKeyIndex
-
- getRightExpression() - Method in class net.sf.jsqlparser.expression.BinaryExpression
-
- getRightExpression() - Method in class net.sf.jsqlparser.expression.operators.relational.ExistsExpression
-
- getRightItem() - Method in class net.sf.jsqlparser.statement.select.Join
-
Returns the right item of the join
- getRightItemsList() - Method in class net.sf.jsqlparser.expression.operators.relational.InExpression
-
- getRowCount() - Method in class net.sf.jsqlparser.statement.select.Limit
-
- getRowCount() - Method in class net.sf.jsqlparser.statement.select.Top
-
- getSchemaName() - Method in class net.sf.jsqlparser.schema.Table
-
- getSelectBody() - Method in class net.sf.jsqlparser.statement.create.view.CreateView
-
- getSelectBody() - Method in class net.sf.jsqlparser.statement.select.Select
-
- getSelectBody() - Method in class net.sf.jsqlparser.statement.select.SubSelect
-
- getSelectBody() - Method in class net.sf.jsqlparser.statement.select.WithItem
-
The
SelectBody of this WITH item is the part after the "AS"
keyword
- getSelectItems() - Method in class net.sf.jsqlparser.statement.select.PlainSelect
-
The
SelectItems in this query (for example the A,B,C in "SELECT
A,B,C")
- getSelectVisitor() - Method in class net.sf.jsqlparser.util.deparser.ExpressionDeParser
-
- getSelectVisitor() - Method in class net.sf.jsqlparser.util.deparser.InsertDeParser
-
- getSelectVisitor() - Method in class net.sf.jsqlparser.util.deparser.ReplaceDeParser
-
- getSingleInItems() - Method in class net.sf.jsqlparser.statement.select.Pivot
-
- getStringExpression() - Method in class net.sf.jsqlparser.expression.BinaryExpression
-
- getStringExpression() - Method in class net.sf.jsqlparser.expression.operators.arithmetic.Addition
-
- getStringExpression() - Method in class net.sf.jsqlparser.expression.operators.arithmetic.BitwiseAnd
-
- getStringExpression() - Method in class net.sf.jsqlparser.expression.operators.arithmetic.BitwiseOr
-
- getStringExpression() - Method in class net.sf.jsqlparser.expression.operators.arithmetic.BitwiseXor
-
- getStringExpression() - Method in class net.sf.jsqlparser.expression.operators.arithmetic.Concat
-
- getStringExpression() - Method in class net.sf.jsqlparser.expression.operators.arithmetic.Division
-
- getStringExpression() - Method in class net.sf.jsqlparser.expression.operators.arithmetic.Modulo
-
- getStringExpression() - Method in class net.sf.jsqlparser.expression.operators.arithmetic.Multiplication
-
- getStringExpression() - Method in class net.sf.jsqlparser.expression.operators.arithmetic.Subtraction
-
- getStringExpression() - Method in class net.sf.jsqlparser.expression.operators.conditional.AndExpression
-
- getStringExpression() - Method in class net.sf.jsqlparser.expression.operators.conditional.OrExpression
-
- getStringExpression() - Method in class net.sf.jsqlparser.expression.operators.relational.EqualsTo
-
- getStringExpression() - Method in class net.sf.jsqlparser.expression.operators.relational.ExistsExpression
-
- getStringExpression() - Method in class net.sf.jsqlparser.expression.operators.relational.GreaterThan
-
- getStringExpression() - Method in class net.sf.jsqlparser.expression.operators.relational.GreaterThanEquals
-
- getStringExpression() - Method in class net.sf.jsqlparser.expression.operators.relational.LikeExpression
-
- getStringExpression() - Method in class net.sf.jsqlparser.expression.operators.relational.Matches
-
- getStringExpression() - Method in class net.sf.jsqlparser.expression.operators.relational.MinorThan
-
- getStringExpression() - Method in class net.sf.jsqlparser.expression.operators.relational.MinorThanEquals
-
- getStringExpression() - Method in class net.sf.jsqlparser.expression.operators.relational.NotEqualsTo
-
- getStringList(List<?>) - Static method in class net.sf.jsqlparser.statement.select.PlainSelect
-
List the toString out put of the objects in the List comma separated.
- getStringList(List<?>, boolean, boolean) - Static method in class net.sf.jsqlparser.statement.select.PlainSelect
-
List the toString out put of the objects in the List that can be comma
separated.
- getStringValue() - Method in class net.sf.jsqlparser.expression.LongValue
-
- getSubSelect() - Method in class net.sf.jsqlparser.expression.AllComparisonExpression
-
- getSubSelect() - Method in class net.sf.jsqlparser.expression.AnyComparisonExpression
-
- getSubSelect() - Method in class net.sf.jsqlparser.statement.select.LateralSubSelect
-
- GetSuffix(int) - Method in class net.sf.jsqlparser.parser.SimpleCharStream
-
Get the suffix.
- getSwitchExpression() - Method in class net.sf.jsqlparser.expression.CaseExpression
-
- getTable() - Method in class net.sf.jsqlparser.schema.Column
-
- getTable() - Method in class net.sf.jsqlparser.statement.create.index.CreateIndex
-
The table on which the index is to be created
- getTable() - Method in class net.sf.jsqlparser.statement.create.table.CreateTable
-
The name of the table to be created
- getTable() - Method in class net.sf.jsqlparser.statement.create.table.ForeignKeyIndex
-
- getTable() - Method in class net.sf.jsqlparser.statement.delete.Delete
-
- getTable() - Method in class net.sf.jsqlparser.statement.insert.Insert
-
- getTable() - Method in class net.sf.jsqlparser.statement.replace.Replace
-
- getTable() - Method in class net.sf.jsqlparser.statement.select.AllTableColumns
-
- getTable() - Method in class net.sf.jsqlparser.statement.truncate.Truncate
-
- getTable() - Method in class net.sf.jsqlparser.statement.update.Update
-
- getTableList(Delete) - Method in class net.sf.jsqlparser.util.TablesNamesFinder
-
Main entry for this Tool class.
- getTableList(Insert) - Method in class net.sf.jsqlparser.util.TablesNamesFinder
-
Main entry for this Tool class.
- getTableList(Replace) - Method in class net.sf.jsqlparser.util.TablesNamesFinder
-
Main entry for this Tool class.
- getTableList(Select) - Method in class net.sf.jsqlparser.util.TablesNamesFinder
-
Main entry for this Tool class.
- getTableList(Update) - Method in class net.sf.jsqlparser.util.TablesNamesFinder
-
Main entry for this Tool class.
- getTableOptionsStrings() - Method in class net.sf.jsqlparser.statement.create.table.CreateTable
-
A list of options (as simple strings) of this table definition, as
("TYPE", "=", "MYISAM")
- getTabSize(int) - Method in class net.sf.jsqlparser.parser.SimpleCharStream
-
- getThenExpression() - Method in class net.sf.jsqlparser.expression.WhenClause
-
- getToken(int) - Method in class net.sf.jsqlparser.parser.CCJSqlParser
-
Get the specific Token.
- getTop() - Method in class net.sf.jsqlparser.statement.select.PlainSelect
-
- getType() - Method in class net.sf.jsqlparser.expression.CastExpression
-
- getType() - Method in class net.sf.jsqlparser.statement.create.table.Index
-
The type of this index: "PRIMARY KEY", "UNIQUE", "INDEX"
- getType() - Method in class net.sf.jsqlparser.statement.drop.Drop
-
- getUsingColumns() - Method in class net.sf.jsqlparser.statement.select.Join
-
Returns the "USING" list of
Columns (if
any)
- getValue() - Method in class net.sf.jsqlparser.expression.DateValue
-
- getValue() - Method in class net.sf.jsqlparser.expression.DoubleValue
-
- getValue() - Method in class net.sf.jsqlparser.expression.LongValue
-
- getValue() - Method in class net.sf.jsqlparser.expression.StringValue
-
- getValue() - Method in class net.sf.jsqlparser.expression.TimestampValue
-
- getValue() - Method in class net.sf.jsqlparser.expression.TimeValue
-
- getValue() - Method in class net.sf.jsqlparser.parser.Token
-
An optional attribute value of the Token.
- getView() - Method in class net.sf.jsqlparser.statement.create.view.CreateView
-
In the syntax tree, a view looks and acts just like a Table.
- getWhenClauses() - Method in class net.sf.jsqlparser.expression.CaseExpression
-
- getWhenExpression() - Method in class net.sf.jsqlparser.expression.WhenClause
-
- getWhere() - Method in class net.sf.jsqlparser.statement.delete.Delete
-
- getWhere() - Method in class net.sf.jsqlparser.statement.select.PlainSelect
-
- getWhere() - Method in class net.sf.jsqlparser.statement.update.Update
-
- getWholeColumnName() - Method in class net.sf.jsqlparser.schema.Column
-
- getWholeTableName() - Method in class net.sf.jsqlparser.schema.Table
-
- getWithItemList() - Method in class net.sf.jsqlparser.statement.select.WithItem
-
The
SelectItems in this WITH (for example the A,B,C in "WITH
mywith (A,B,C) AS ...")
- getWithItemsList() - Method in class net.sf.jsqlparser.statement.select.Select
-
- GreaterThan - Class in net.sf.jsqlparser.expression.operators.relational
-
- GreaterThan() - Constructor for class net.sf.jsqlparser.expression.operators.relational.GreaterThan
-
- GreaterThanEquals - Class in net.sf.jsqlparser.expression.operators.relational
-
- GreaterThanEquals() - Constructor for class net.sf.jsqlparser.expression.operators.relational.GreaterThanEquals
-
- GroupByColumnReferences() - Method in class net.sf.jsqlparser.parser.CCJSqlParser
-